package envoy.data;

/**
 * Represents a unique user with a unique, numeric ID, a name and a current
 * {@link UserStatus}.<br>
 * <br>
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>User.java</strong><br>
 * Created: <strong>28.12.2019</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Common v0.2-alpha
 */
public class User extends Contact {

	/**
	 * This enumeration defines all possible statuses a user can have.
	 *
	 * @since Envoy Common v0.2-alpha
	 */
	public static enum UserStatus {

		/**
		 * select this, if a user is online and can be interacted with
		 */
		ONLINE,

		/**
		 * select this, if a user is online but unavailable at the moment (sudden
		 * interruption)
		 */
		AWAY,

		/**
		 * select this, if a user is online but unavailable at the moment (polite way)
		 */
		BUSY,

		/**
		 * select this, if a user is offline
		 */
		OFFLINE;
	}

	private UserStatus status;

	private static final long serialVersionUID = 1L;

	/**
	 * Initializes a {@link User}. <br>
	 * The {@link UserStatus} is set to {@link UserStatus#ONLINE}.
	 *
	 * @param id   unique ID
	 * @param name user name
	 * @since Envoy Common v0.2-alpha
	 */
	public User(long id, String name) {
		super(id, name);
		status = UserStatus.ONLINE;
	}

	/**
	 * Initializes a {@link User}.
	 *
	 * @param id     unique ID
	 * @param name   user name
	 * @param status the status of the user
	 * @since Envoy Common v0.2-alpha
	 */
	public User(long id, String name, UserStatus status) {
		super(id, name);
		this.status = status;
	}

	@Override
	public String toString() { return String.format("User[id=%d,name=%s,status=%s]", getID(), getName(), status); }

	/**
	 * @return the current status of this user
	 * @since Envoy Common v0.2-alpha
	 */
	public UserStatus getStatus() { return status; }

	/**
	 * @param status the next status of this user
	 * @since Envoy Common v0.2-alpha
	 */
	public void setStatus(UserStatus status) { this.status = status; }
}
